<?php 
/**
 * Adds About_Widget widget.
 */
class About_Widget extends WP_Widget {

  /**
   * Register widget with WordPress.
   */
  function __construct() {
    parent::__construct(
      'about_widget', // Base ID
      esc_html__( 'About Widget', 'text_domain' ), // Name
      array( 'description' => esc_html__( 'A About Widget', 'text_domain' ), ) // Args
    );
  }

  /**
   * Front-end display of widget.
   *
   * @see WP_Widget::widget()
   *
   * @param array $args     Widget arguments.
   * @param array $instance Saved values from database.
   */
  public function widget( $args, $instance ) {
    echo $args['before_widget'];
    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
    }
    
    echo '
            
            <p>'.$instance['text'].'</p>
            <div class="footer-sosmed"> <a href="'.$instance['fb'].'" title="">
              <div class="item"><i class="fa fa-facebook"></i></div>
              </a> <a href="'.$instance['twt'].'" title="">
              <div class="item"><i class="fa fa-twitter"></i></div>
              </a> <a href="'.$instance['inta'].'" title="">
              <div class="item"><i class="fa fa-instagram"></i></div>
              </a> <a href="'.$instance['pint'].'" title="">
              <div class="item"><i class="fa fa-pinterest"></i></div>
              </a> </div>
          ';
    echo $args['after_widget'];
  }

  /**
   * Back-end widget form.
   *
   * @see WP_Widget::form()
   *
   * @param array $instance Previously saved values from database.
   */
  public function form( $instance ) {
    $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'About Club', 'text_domain' );
    $text = ! empty( $instance['text'] ) ? $instance['text'] : esc_html__( 'This template is a micro niche for business categories, namely Pro Soccer business. there was an excess of this template is using HTML/CSS. Condimentum aliquam, mollit magna velit nec, tempor cursus vitae sit aliquet neque purus. Ultrices lacus proin conubia dictum tempus, tempor pede vitae faucibus', 'text_domain' );
    $fb = ! empty( $instance['fb'] ) ? $instance['fb'] : esc_html__( '#', 'text_domain' );
    $twt = ! empty( $instance['twt'] ) ? $instance['twt'] : esc_html__( '#', 'text_domain' );
    $inta = ! empty( $instance['twt'] ) ? $instance['twt'] : esc_html__( '#', 'text_domain' );
    $pint = ! empty( $instance['twt'] ) ? $instance['twt'] : esc_html__( '#', 'text_domain' );
    ?>
    <p>
    <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
    </p>
    <p>
    <label for="<?php echo $this->get_field_id( 'text' ); ?>"><?php esc_html_e( 'Text:' ); ?></label> 
    
    
    <textarea rows="4" cols="50" class="widefat" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>">
    <?php echo esc_attr( $text ); ?>
    </textarea></p>
    <p>
    <label for="<?php echo $this->get_field_id( 'fb' ); ?>"><?php esc_html_e( 'Facebook:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'fb' ); ?>" name="<?php echo $this->get_field_name( 'fb' ); ?>" type="text" value="<?php echo esc_attr( $fb ); ?>">
    </p>
    <p>
    <label for="<?php echo $this->get_field_id( 'twt' ); ?>"><?php esc_html_e( 'Twitter:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'twt' ); ?>" name="<?php echo $this->get_field_name( 'twt' ); ?>" type="text" value="<?php echo esc_attr( $twt ); ?>">
    </p>
    <p>
    <label for="<?php echo $this->get_field_id( 'inta' ); ?>"><?php esc_html_e( 'Instagram:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'inta' ); ?>" name="<?php echo $this->get_field_name( 'inta' ); ?>" type="text" value="<?php echo esc_attr( $inta ); ?>">
    </p>
    <p>
    <label for="<?php echo $this->get_field_id( 'pint' ); ?>"><?php esc_html_e( 'Pinterest:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'pint' ); ?>" name="<?php echo $this->get_field_name( 'pint' ); ?>" type="text" value="<?php echo esc_attr( $pint ); ?>">
    </p>
    <?php 
  }

  /**
   * Sanitize widget form values as they are saved.
   *
   * @see WP_Widget::update()
   *
   * @param array $new_instance Values just sent to be saved.
   * @param array $old_instance Previously saved values from database.
   *
   * @return array Updated safe values to be saved.
   */
  public function update( $new_instance, $old_instance ) {
    $instance = array();
    $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
    $instance['text'] = ( ! empty( $new_instance['text'] ) ) ? strip_tags( $new_instance['text'] ) : '';
    $instance['fb'] = ( ! empty( $new_instance['fb'] ) ) ? strip_tags( $new_instance['fb'] ) : '';
    $instance['twt'] = ( ! empty( $new_instance['twt'] ) ) ? strip_tags( $new_instance['twt'] ) : '';
    $instance['inta'] = ( ! empty( $new_instance['inta'] ) ) ? strip_tags( $new_instance['inta'] ) : '';
    $instance['pint'] = ( ! empty( $new_instance['pint'] ) ) ? strip_tags( $new_instance['pint'] ) : '';

    return $instance;
  }

} // class About_Widget

function register_about_widget() {
    register_widget( 'About_Widget' );
}
add_action( 'widgets_init', 'register_about_widget' );
/**
 * Adds About_Widget widget.
 */
class Recentpost_Widget extends WP_Widget {

  /**
   * Register widget with WordPress.
   */
  function __construct() {
    parent::__construct(
      'recentpost_widget', // Base ID
      esc_html__( 'Recent Post Widget', 'text_domain' ), // Name
      array( 'description' => esc_html__( 'A Recentpost Widget', 'text_domain' ), ) // Args
    );
  }

  /**
   * Front-end display of widget.
   *
   * @see WP_Widget::widget()
   *
   * @param array $args     Widget arguments.
   * @param array $instance Saved values from database.
   */
  public function widget( $args, $instance ) {
    echo $args['before_widget'];
    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
    }
    $arg = array(
        'post_status' => 'publish',
        'post_type'   => 'post',
        'posts_per_page' => 2
      );
      $query = new WP_Query( $arg );
      if ($query->have_posts()) {
        while ( $query->have_posts()) {$query->the_post();
  
    
    echo '
              <div class="footer-blog-item">
                <div class="footer-blog-lead">
                  <a href="'.get_the_permalink().'" title="">'.get_the_title().'</a>
                </div>
                <div class="footer-blog-date">
                  '.get_the_date('F j, Y' ).'
                </div>
              </div>
              ';}}
              
    echo $args['after_widget'];
  }

  /**
   * Back-end widget form.
   *
   * @see WP_Widget::form()
   *
   * @param array $instance Previously saved values from database.
   */
  public function form( $instance ) {
    $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'About Club', 'text_domain' );
    
    ?>
    <p>
    <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
    </p>
    
    <?php 
  }

  /**
   * Sanitize widget form values as they are saved.
   *
   * @see WP_Widget::update()
   *
   * @param array $new_instance Values just sent to be saved.
   * @param array $old_instance Previously saved values from database.
   *
   * @return array Updated safe values to be saved.
   */
  public function update( $new_instance, $old_instance ) {
    $instance = array();
    $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
    

    return $instance;
  }

} // class About_Widget

function register_recentpost_widget() {
    register_widget( 'Recentpost_Widget' );
}
add_action( 'widgets_init', 'register_recentpost_widget' );



class widget_contact extends WP_Widget { 
  
  // Widget Settings
  function widget_contact() {
    $widget_ops = array('description' => __('Display your Contact Informations', 'resala-framework') );
    $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'contact' );
    parent::__construct( 'contact', __('resala.Contact', 'resala-framework'), $widget_ops, $control_ops );
  }
  
  // Widget Output
  function widget($args, $instance) {
    extract($args);
    $title = apply_filters('widget_title', esc_html($instance['title']));
    // ------
    echo $before_widget;
    echo $before_title . esc_html($title) . $after_title;
    ?>
    
   
    <div class="footer-getintouch">
      <?php if($instance['phone']): ?>
                <div class="footer-getintouch-item">
                  <div class="icon">
                    <b class="fa fa-phone"></b>
                  </div>
                  <div class="desc">
                    <div class="desc-1"><?php _e( 'Phone', 'resala' ) ?></div>
                    <div class="desc-2">:</div>
                    <div class="desc-3"><?php echo wp_kses_post($instance['phone']); ?></div>
                  </div>
                </div>
                <?php endif; ?>
                 <?php if($instance['email']): ?>
                <div class="footer-getintouch-item">
                  <div class="icon">
                    <b class="fa fa-envelope "></b>
                  </div>
                  <div class="desc">
                    <div class="desc-1"><?php _e( 'E-Mail', 'resala' ) ?></div>
                    <div class="desc-2">:</div>
                    <div class="desc-3"><a href="mailto:<?php echo esc_html($instance['email']); ?>" title=""><?php echo esc_html($instance['email']); ?></a></div>
                  </div>
                </div>
                <?php endif; ?>
                <?php if($instance['web']): ?>
                <div class="footer-getintouch-item">
                  <div class="icon">
                    <b class="fa fa-globe"></b>
                  </div>
                  <div class="desc">
                    <div class="desc-1"><?php _e( 'Website', 'resala' ) ?> </div>
                    <div class="desc-2">:</div>
                    <div class="desc-3"><?php echo esc_html($instance['web']); ?></div>
                  </div>
                </div>
                <?php endif; ?>
                 <?php if($instance['address']): ?>
                <div class="footer-getintouch-item">
                  <div class="icon">
                    <b class="fa fa-map-marker"></b>
                  </div>
                  <div class="desc">
                    <div class="desc-1"><?php _e( 'Address', 'resala' ) ?> </div>
                    <div class="desc-2">:</div>
                    <div class="desc-3"><?php echo wp_kses_post($instance['address']); ?></div>
                  </div>
                </div>
                <?php endif; ?>
              </div>
    
    <?php
    echo $after_widget;
    // ------
  }
  
  // Update
  function update( $new_instance, $old_instance ) {  
    $instance = $old_instance; 
    
    $instance['title'] = $new_instance['title'];
    $instance['address'] = $new_instance['address'];
    $instance['phone'] = $new_instance['phone'];
    $instance['fax'] = $new_instance['fax'];
    $instance['email'] = $new_instance['email'];
    $instance['web'] = $new_instance['web'];

    return $instance;
  }
  
  // Backend Form
  function form($instance) {
    
    //$defaults = array( 'title' => 'Twitter Widget', 'posts' => '3', 'username' => 'helloresala' ); // Default Values
    $defaults = array('title' => 'Contact Info', 'address' => '', 'phone' => '', 'fax' => '', 'email' => '', 'web' => '');
    $instance = wp_parse_args((array) $instance, $defaults); ?>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">Title:</label><br />
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">Phone:</label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" value="<?php echo esc_attr($instance['phone']); ?>" />
    </p>
     <p>
      <label for="<?php echo esc_attr($this->get_field_id('email')); ?>">Email:</label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" value="<?php echo esc_attr($instance['email']); ?>" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('web')); ?>">Website URL (without http://):</label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('web')); ?>" name="<?php echo esc_attr($this->get_field_name('web')); ?>" value="<?php echo esc_attr($instance['web']); ?>" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('address')); ?>">Address:</label>
      <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" value="<?php echo esc_attr($instance['address']); ?>" />
    </p>
   
    
    <?php }
}

// Add Widget
function widget_contact_init() {
  register_widget('widget_contact');
}
add_action('widgets_init', 'widget_contact_init');
?>